Name:		shared-mime-info
Version:	1.0
Release:	%mkrel 3
Summary:	Shared MIME-Info Specification
Group:		Graphical desktop/Other
#gw main is GPL, test program is LGPL
License:	GPL+ and LGPLv2+
URL:		http://www.freedesktop.org/wiki/Software/shared-mime-info
Source0:	http://freedesktop.org/~hadess/%{name}-%{version}.tar.xz
Source1:	defaults.list
# KDE 4 overrides.
Source2:	mimeapps.list
Patch0:		shared-mime-info-xz.patch
# (fc) 0.22-2mdv fix VHDL vs CRT magic detection (Mdv bug #31603)
Patch4:		shared-mime-info-0.80-vhdl.patch
BuildRequires:	libxml2-devel
BuildRequires:  libxml2-utils
BuildRequires:	glib2-devel
BuildRequires:  intltool

%description
This is the freedesktop.org shared MIME info database.

Many programs and desktops use the MIME system to represent the types of
files. Frequently, it is necessary to work out the correct MIME type for
a file. This is generally done by examining the file's name or contents,
and looking up the correct MIME type in a database.

For interoperability, it is useful for different programs to use the
same database so that different programs agree on the type of a file,
and new rules for determining the type apply to all programs.

This specification attempts to unify the type-guessing systems currently
in use by GNOME, KDE and ROX. Only the name-to-type and contents-to-type
mappings are covered by this spec; other MIME type information, such as
the default handler for a particular type, or the icon to use to display
it in a file manager, are not covered since these are a matter of style.

In addition, freedesktop.org provides a shared database in this format
to avoid inconsistencies between desktops. This database has been
created by converting the existing KDE and GNOME databases to the new
format and merging them together.

%prep
%setup -q
%apply_patches

%build
%configure2_5x --disable-update-mimedb
#gw parallel make fails in 0.90
make

%install
rm -rf %{buildroot}
%makeinstall_std

mkdir -p %{buildroot}%{_datadir}/applications
install -m 644 %{SOURCE1} %{SOURCE2} %{buildroot}%{_datadir}/applications
mkdir -p %{buildroot}%{_datadir}/mime/{application,image,message,multipart,text,audio,inode,model,packages,video}

touch %{buildroot}%{_datadir}/mime/{XMLnamespaces,aliases,globs,magic,subclasses,mime.cache}

## remove these bogus files
%{__rm} -rf %{buildroot}%{_datadir}/locale/*

# automatic mime database update on rpm installs/removals
# (see http://wiki.mandriva.com/en/Rpm_filetriggers)
install -d %buildroot%{_var}/lib/rpm/filetriggers
cat > %buildroot%{_var}/lib/rpm/filetriggers/mime-database.filter << EOF
^./usr/share/mime/packages/[^/]*\.xml$
EOF
cat > %buildroot%{_var}/lib/rpm/filetriggers/mime-database.script << EOF
#!/bin/sh
/usr/bin/update-mime-database /usr/share/mime > /dev/null
EOF
chmod 755 %buildroot%{_var}/lib/rpm/filetriggers/mime-database.script


%check
make check

%post
%update_mime_database

#FIXME: Can this trigger be removed ?
%triggerun -- shared-mime-info < 0.20-3mdv
%update_mime_database

%files
%doc README shared-mime-info-spec.xml NEWS
%_bindir/update-mime-database
%dir %{_datadir}/mime/
%{_datadir}/applications/defaults.list
%{_datadir}/applications/mimeapps.list
%dir %{_datadir}/mime/application  
%dir %{_datadir}/mime/image  
%dir %{_datadir}/mime/message  
%dir %{_datadir}/mime/multipart  
%dir %{_datadir}/mime/text
%dir %{_datadir}/mime/audio        
%dir %{_datadir}/mime/inode  
%dir %{_datadir}/mime/model    
%dir %{_datadir}/mime/packages   
%dir %{_datadir}/mime/video
%ghost %{_datadir}/mime/XMLnamespaces
%ghost %{_datadir}/mime/aliases
%ghost %{_datadir}/mime/globs
%ghost %{_datadir}/mime/magic
%ghost %{_datadir}/mime/subclasses
%ghost %{_datadir}/mime/mime.cache
%{_datadir}/mime/packages/freedesktop.org.xml
%_mandir/man1/update-mime-database.1*
%_datadir/pkgconfig/shared-mime-info.pc
%{_var}/lib/rpm/filetriggers/mime-database.*


%changelog

* Mon Jan 14 2013 umeabot <umeabot> 1.0-3.mga3
+ Revision: 381961
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jun 17 2012 fwang <fwang> 1.0-2.mga3
+ Revision: 261139
- fix bug#5665: msooxml files should be opened with libreoffice

* Sun Jan 22 2012 fwang <fwang> 1.0-1.mga2
+ Revision: 199756
- new version 1.0

* Wed Jan 11 2012 ovitters <ovitters> 0.91-2.mga2
+ Revision: 195021
- add patch from git to fix ppm detection (for gnome-boxes)

* Mon Sep 19 2011 fwang <fwang> 0.91-1.mga2
+ Revision: 145336
- rediff xz patch
- new version 0.91

* Tue Apr 26 2011 ahmad <ahmad> 0.90-5.mga1
+ Revision: 91844
- mimeapps.list: add application/x-rpm=mageia-gurpmi.desktop, so that it works
  for dolphin (and for Gvfs/GIO based apps)

* Tue Apr 26 2011 ahmad <ahmad> 0.90-4.mga1
+ Revision: 91244
- defaults.list: change the default application for application/x-rpm to
  mageia-gurpmi.desktop instead of the non-existent mandriva-gurpmi.desktop (mga#992)

* Thu Mar 24 2011 boklm <boklm> 0.90-3.mga1
+ Revision: 76208
- rebuild for bug #497

* Mon Mar 21 2011 ahmad <ahmad> 0.90-2.mga1
+ Revision: 75298
- disable parallel make, it fails with > -j2
- add x-scheme-handler/http* to defaults.list, so that gvfs-open can work with
  https links, should fix (mga#400)
- re-enable parallel make, seems to work now

* Sat Jan 15 2011 dmorgan <dmorgan> 0.90-1.mga1
+ Revision: 18268
- Add comment
- imported package shared-mime-info

